# Data extraction for longitudinal ENIGMA pipeline 
# Rachel Brouwer (March 2016)
#!/bin/bash 

Parent_baseline=/enigma/longitudinal/baseline/
Parent_followup=/enigma/longitudinal/followup/
Subjectfile=/enigma/longitudinal/followup/longitudinal_ENIGMA_subjects.txt


# No need to edit below this line

OUTPUT=ENIGMA_LONG.csv 

# remove output file if already present
if [ -f $OUTPUT ]
then 
rm $OUTPUT
fi

# First define which phenotypes to extract
# GLOBAL measures
GLOBAL='IntraCranialVol BrainSegNotVent lhCortexVol rhCortexVol lhCorticalWhiteMatterVol rhCorticalWhiteMatterVol'
GLOBAL2='3rd-Ventricle 4th-Ventricle'
GLOBALLRaparc='MeanThickness WhiteSurfArea'
GLOBALLRaseg='Cerebellum-White-Matter Cerebellum-Cortex Lateral-Ventricle Inf-Lat-Vent choroid-plexus'

# Subcortical measures
SUB='thal caud put pal hippo amyg accumb'
SUBnames='Thalamus Caudate Putamen Pallidum Hippocampus Amygdala Accumbens-area'

# LOCAL measures cortical thickness and surface area

LOCAL='bankssts caudalanteriorcingulate caudalmiddlefrontal cuneus entorhinal fusiform inferiorparietal inferiortemporal isthmuscingulate lateraloccipital lateralorbitofrontal lingual medialorbitofrontal middletemporal parahippocampal paracentral parsopercularis parsorbitalis parstriangularis pericalcarine postcentral posteriorcingulate precentral precuneus rostralanteriorcingulate rostralmiddlefrontal superiorfrontal superiorparietal superiortemporal supramarginal frontalpole temporalpole transversetemporal insula'

# Create name variables to write to output
GLOBAL_base=`printf ',%s_base' $GLOBAL`
GLOBAL_fup=`printf ',%s_fup' $GLOBAL`
GLOBAL2_base=`printf ',%s_base' $GLOBAL2`
GLOBAL2_fup=`printf ',%s_fup' $GLOBAL2`
L_GLOBALLRaparc_base=`printf ',L_%s_base' $GLOBALLRaparc`
R_GLOBALLRaparc_base=`printf ',R_%s_base' $GLOBALLRaparc`
L_GLOBALLRaparc_fup=`printf ',L_%s_fup' $GLOBALLRaparc`
R_GLOBALLRaparc_fup=`printf ',R_%s_fup' $GLOBALLRaparc`
L_GLOBALLRaseg_base=`printf ',L_%s_base' $GLOBALLRaseg`
R_GLOBALLRaseg_base=`printf ',R_%s_base' $GLOBALLRaseg`
L_GLOBALLRaseg_fup=`printf ',L_%s_fup' $GLOBALLRaseg`
R_GLOBALLRaseg_fup=`printf ',R_%s_fup' $GLOBALLRaseg`
L_SUB_base=`printf ',L_%s_base' $SUB`
R_SUB_base=`printf ',R_%s_base' $SUB`
L_SUB_fup=`printf ',L_%s_fup' $SUB`
R_SUB_fup=`printf ',R_%s_fup' $SUB`
L_LOCAL_THICK_base=`printf ',L_%s_thickavg_base' $LOCAL`
R_LOCAL_THICK_base=`printf ',R_%s_thickavg_base' $LOCAL`
L_LOCAL_THICK_fup=`printf ',L_%s_thickavg_fup' $LOCAL`
R_LOCAL_THICK_fup=`printf ',R_%s_thickavg_fup' $LOCAL`
L_LOCAL_SURF_base=`printf ',L_%s_surfavg_base' $LOCAL`
R_LOCAL_SURF_base=`printf ',R_%s_surfavg_base' $LOCAL`
L_LOCAL_SURF_fup=`printf ',L_%s_surfavg_fup' $LOCAL`
R_LOCAL_SURF_fup=`printf ',R_%s_surfavg_fup' $LOCAL`

# echo names to output
echo SubID_base,SubID_fup,fup_duration $GLOBAL_base $GLOBAL2_base $L_GLOBALLRaseg_base $R_GLOBALLRaseg_base $L_GLOBALLRaparc_base $R_GLOBALLRaparc_base $L_SUB_base $R_SUB_base $L_LOCAL_THICK_base $R_LOCAL_THICK_base $L_LOCAL_SURF_base $R_LOCAL_SURF_base $GLOBAL_fup $GLOBAL2_fup $L_GLOBALLRaseg_fup $R_GLOBALLRaseg_fup $L_GLOBALLRaparc_fup $R_GLOBALLRaparc_fup $L_SUB_fup $R_SUB_fup $L_LOCAL_THICK_fup $R_LOCAL_THICK_fup $L_LOCAL_SURF_fup $R_LOCAL_SURF_fup > $OUTPUT
# remove additional spaces
sed 's/ ,/,/g' < $OUTPUT > temp
mv temp $OUTPUT

while read line
do
base=`echo $line | awk '{ print $1 }'`
fup=`echo $line | awk '{ print $2 }'`
fup_duration=`echo $line | awk '{ print $3 }'`

# check whether all subjects can be found and whether there is output
missing=""

for file in aseg.stats lh.aparc.stats rh.aparc.stats
do
if [ ! -f ${Parent_baseline}/${base}/stats/${file} ]
then
echo "WARNING: File $file for $base not found; please check your subject list and output"
missing=1
fi
if [ ! -f ${Parent_followup}/${fup}/stats/${file} ]
then
echo "WARNING: File $file for $fup not found; please check your subject list and output"
missing=1
fi
done

if [[ $missing != 1 ]]
then

printf "%s,%s,%s" $base $fup ${fup_duration} >> $OUTPUT


# First everything of baseline, then everything of followup
for m in ${Parent_baseline}/${base} ${Parent_followup}/${fup}
do

for x in $GLOBAL
do
printf ",%1.7g" `grep ${x} ${m}/stats/aseg.stats| awk -F, 'NR == 1 {print $4}'` >> $OUTPUT
done

for x in $GLOBAL2
do
printf ",%g" `grep ${x} ${m}/stats/aseg.stats| awk '{print $4}'` >> $OUTPUT
done

for side in Left Right
do
for x in $GLOBALLRaseg
do
find=`echo $side $x | awk '{print $1"-"$2}'`
printf ",%g" `cat ${m}/stats/aseg.stats| grep ${find}| awk '{print $4}'` >> $OUTPUT
done
done # global structures from aseg.stats

for side in lh.aparc.stats rh.aparc.stats
do
for x in $GLOBALLRaparc
do
printf ",%g" `cat ${m}/stats/${side}| grep -w ${x}| awk -F, '{print $4}'` >> $OUTPUT
done
done # global structures from aparc.stats


# SUBCORTICAL

for side in Left Right
do
for x in $SUBnames
do
find=`echo $side $x | awk '{print $1"-"$2}'`
printf ",%g" `cat ${m}/stats/aseg.stats | grep ${find}| awk '{print $4}'` >> $OUTPUT
done
done # subcortical structures


# LOCAL THICKNESS
for side in lh.aparc.stats rh.aparc.stats
do
for x in $LOCAL
do 
printf ",%g" `cat ${m}/stats/${side}| grep -w ${x}| awk '{print $5}'` >> $OUTPUT
done
done

# LOCAL SURFACE
for side in lh.aparc.stats rh.aparc.stats
do
for x in $LOCAL
do 
printf ",%g" `cat ${m}/stats/${side}| grep -w ${x}| awk '{print $3}'` >> $OUTPUT
done
done

done # baseline / fup
# newline
echo "" >> $OUTPUT 
fi

done < ${Subjectfile}
 



